<?php

namespace Litecms\Register2\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Register2\Http\Requests\Register2Request;
use Litecms\Register2\Interfaces\Register2RepositoryInterface;
use Litecms\Register2\Models\Register2;

/**
 * Resource controller class for register2.
 */
class Register2ResourceController extends BaseController
{

    /**
     * Initialize register2 resource controller.
     *
     * @param type Register2RepositoryInterface $register2
     *
     * @return null
     */
    public function __construct(Register2RepositoryInterface $register2)
    {
        parent::__construct();
        $this->repository = $register2;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Register2\Repositories\Criteria\Register2ResourceCriteria::class);
    }

    /**
     * Display a list of register2.
     *
     * @return Response
     */
    public function index(Register2Request $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Register2\Repositories\Presenter\Register2Presenter::class)
                ->$function();
        }

        $register2s = $this->repository->paginate();

        return $this->response->title(trans('register2::register2.names'))
            ->view('register2::register2.index', true)
            ->data(compact('register2s'))
            ->output();
    }

    /**
     * Display register2.
     *
     * @param Request $request
     * @param Model   $register2
     *
     * @return Response
     */
    public function show(Register2Request $request, Register2 $register2)
    {

        if ($register2->exists) {
            $view = 'register2::register2.show';
        } else {
            $view = 'register2::register2.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('register2::register2.name'))
            ->data(compact('register2'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new register2.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(Register2Request $request)
    {

        $register2 = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('register2::register2.name')) 
            ->view('register2::register2.create', true) 
            ->data(compact('register2'))
            ->output();
    }

    /**
     * Create new register2.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(Register2Request $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $register2                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('register2::register2.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('register2/register2/' . $register2->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/register2/register2'))
                ->redirect();
        }

    }

    /**
     * Show register2 for editing.
     *
     * @param Request $request
     * @param Model   $register2
     *
     * @return Response
     */
    public function edit(Register2Request $request, Register2 $register2)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('register2::register2.name'))
            ->view('register2::register2.edit', true)
            ->data(compact('register2'))
            ->output();
    }

    /**
     * Update the register2.
     *
     * @param Request $request
     * @param Model   $register2
     *
     * @return Response
     */
    public function update(Register2Request $request, Register2 $register2)
    {
        try {
            $attributes = $request->all();

            $register2->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('register2::register2.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('register2/register2/' . $register2->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('register2/register2/' . $register2->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the register2.
     *
     * @param Model   $register2
     *
     * @return Response
     */
    public function destroy(Register2Request $request, Register2 $register2)
    {
        try {

            $register2->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('register2::register2.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('register2/register2/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('register2/register2/' . $register2->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple register2.
     *
     * @param Model   $register2
     *
     * @return Response
     */
    public function delete(Register2Request $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('register2::register2.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('register2/register2'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/register2/register2'))
                ->redirect();
        }

    }

    /**
     * Restore deleted register2s.
     *
     * @param Model   $register2
     *
     * @return Response
     */
    public function restore(Register2Request $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('register2::register2.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/register2/register2'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/register2/register2/'))
                ->redirect();
        }

    }

}
