<?php

namespace Litecms\Register2\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Register2\Models\Register2;

class Register2Policy
{

    /**
     * Determine if the given user can view the register2.
     *
     * @param UserPolicy $user
     * @param Register2 $register2
     *
     * @return bool
     */
    public function view(UserPolicy $user, Register2 $register2)
    {
        if ($user->canDo('register2.register2.view') && $user->isAdmin()) {
            return true;
        }

        return $register2->user_id == user_id() && $register2->user_type == user_type();
    }

    /**
     * Determine if the given user can create a register2.
     *
     * @param UserPolicy $user
     * @param Register2 $register2
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('register2.register2.create');
    }

    /**
     * Determine if the given user can update the given register2.
     *
     * @param UserPolicy $user
     * @param Register2 $register2
     *
     * @return bool
     */
    public function update(UserPolicy $user, Register2 $register2)
    {
        if ($user->canDo('register2.register2.edit') && $user->isAdmin()) {
            return true;
        }

        return $register2->user_id == user_id() && $register2->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given register2.
     *
     * @param UserPolicy $user
     * @param Register2 $register2
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Register2 $register2)
    {
        return $register2->user_id == user_id() && $register2->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given register2.
     *
     * @param UserPolicy $user
     * @param Register2 $register2
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Register2 $register2)
    {
        if ($user->canDo('register2.register2.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given register2.
     *
     * @param UserPolicy $user
     * @param Register2 $register2
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Register2 $register2)
    {
        if ($user->canDo('register2.register2.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
