<?php

namespace Litecms\Register2\Providers;

use Illuminate\Support\ServiceProvider;

class Register2ServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'register2');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'register2');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.register2', function ($app) {
            return $this->app->make('Litecms\Register2\Register2');
        });

                // Bind Register2 to repository
        $this->app->bind(
            'Litecms\Register2\Interfaces\Register2RepositoryInterface',
            \Litecms\Register2\Repositories\Eloquent\Register2Repository::class
        );

        $this->app->register(\Litecms\Register2\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Register2\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.register2'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/register2.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/register2')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/register2')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
